==> jc-1.4.0.tar.gz: soot/coffi/Instruction__5fIrem.h <==
// class soot.coffi.Instruction_Irem

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class b569d3cf8762c695 soot_coffi_Instruction
// @dep_class b6bf9837c124bb0f soot_coffi_Instruction__5fIrem
// @dep_class 741c2648db62361c soot_coffi_Instruction__5fnoargs

// header file dependencies
// @dep_header soot_coffi_Instruction__5fnoargs

#include "soot/coffi/Instruction__5fnoargs.h"

#ifndef _JC_soot_coffi_Instruction__5fIrem_H_
#define _JC_soot_coffi_Instruction__5fIrem_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_soot_coffi_Instruction__5fIrem$sub_refs	_jc_soot_coffi_Instruction__5fIrem$sub_refs;
typedef struct _jc_soot_coffi_Instruction__5fIrem$sub_nonrefs	_jc_soot_coffi_Instruction__5fIrem$sub_nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fIrem$refs	_jc_soot_coffi_Instruction__5fIrem$refs;
typedef struct _jc_soot_coffi_Instruction__5fIrem$nonrefs	_jc_soot_coffi_Instruction__5fIrem$nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fIrem$object	_jc_soot_coffi_Instruction__5fIrem$object;

typedef const struct _jc_soot_coffi_Instruction__5fIrem$vmethods	_jc_soot_coffi_Instruction__5fIrem$vmethods;
typedef const struct _jc_soot_coffi_Instruction__5fIrem$vtable	_jc_soot_coffi_Instruction__5fIrem$vtable;
typedef const struct _jc_soot_coffi_Instruction__5fIrem$vtype	_jc_soot_coffi_Instruction__5fIrem$vtype;

// Constructors
extern void _jc_soot_coffi_Instruction__5fIrem$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_coffi_Instruction__5fIrem$object *);

// Virtual methods structure
struct _jc_soot_coffi_Instruction__5fIrem$vmethods {
};

// Vtable
struct _jc_soot_coffi_Instruction__5fIrem$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_coffi_Instruction$vmethods	soot_coffi_Instruction;
	_jc_soot_coffi_Instruction__5fnoargs$vmethods	soot_coffi_Instruction__5fnoargs;
	_jc_soot_coffi_Instruction__5fIrem$vmethods	soot_coffi_Instruction__5fIrem;
};

// Vtype
struct _jc_soot_coffi_Instruction__5fIrem$vtype {
	_jc_type			type;
	_jc_soot_coffi_Instruction__5fIrem$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fIrem$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fIrem$refs {
    _jc_soot_coffi_Instruction__5fIrem$sub_refs	soot_coffi_Instruction__5fIrem;
    _jc_soot_coffi_Instruction__5fnoargs$sub_refs	soot_coffi_Instruction__5fnoargs;
    _jc_soot_coffi_Instruction$sub_refs	soot_coffi_Instruction;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fIrem$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fIrem$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_coffi_Instruction$sub_nonrefs	soot_coffi_Instruction;
    _jc_soot_coffi_Instruction__5fnoargs$sub_nonrefs	soot_coffi_Instruction__5fnoargs;
    _jc_soot_coffi_Instruction__5fIrem$sub_nonrefs	soot_coffi_Instruction__5fIrem;
};

// Object instance structure
struct _jc_soot_coffi_Instruction__5fIrem$object {
	_jc_soot_coffi_Instruction__5fIrem$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_coffi_Instruction__5fIrem$vtype	*vtype;
	_jc_soot_coffi_Instruction__5fIrem$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_coffi_Instruction__5fIrem$vtype _jc_soot_coffi_Instruction__5fIrem$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_coffi_Instruction__5fIrem, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_coffi_Instruction__5fIrem$class_object;

#endif	/* _JC_soot_coffi_Instruction__5fIrem_H_ */

==> jc-1.4.6.tar.gz: soot/coffi/Instruction__5fIrem.h <==
// class soot.coffi.Instruction_Irem

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class b569d3cf8762c695 soot_coffi_Instruction
// @dep_class b6bf9837c124bb0f soot_coffi_Instruction__5fIrem
// @dep_class 741c2648db62361c soot_coffi_Instruction__5fnoargs

// header file dependencies
// @dep_header soot_coffi_Instruction__5fnoargs

#include "soot/coffi/Instruction__5fnoargs.h"

#ifndef _JC_soot_coffi_Instruction__5fIrem_H_
#define _JC_soot_coffi_Instruction__5fIrem_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_soot_coffi_Instruction__5fIrem$sub_refs	_jc_soot_coffi_Instruction__5fIrem$sub_refs;
typedef struct _jc_soot_coffi_Instruction__5fIrem$sub_nonrefs	_jc_soot_coffi_Instruction__5fIrem$sub_nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fIrem$refs	_jc_soot_coffi_Instruction__5fIrem$refs;
typedef struct _jc_soot_coffi_Instruction__5fIrem$nonrefs	_jc_soot_coffi_Instruction__5fIrem$nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fIrem$object	_jc_soot_coffi_Instruction__5fIrem$object;

typedef const struct _jc_soot_coffi_Instruction__5fIrem$vmethods	_jc_soot_coffi_Instruction__5fIrem$vmethods;
typedef const struct _jc_soot_coffi_Instruction__5fIrem$vtable	_jc_soot_coffi_Instruction__5fIrem$vtable;
typedef const struct _jc_soot_coffi_Instruction__5fIrem$vtype	_jc_soot_coffi_Instruction__5fIrem$vtype;

// Constructors
extern void _jc_soot_coffi_Instruction__5fIrem$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_coffi_Instruction__5fIrem$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_coffi_Instruction__5fIrem$vmethods {
};

// Vtable
struct _jc_soot_coffi_Instruction__5fIrem$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_coffi_Instruction$vmethods	soot_coffi_Instruction;
	_jc_soot_coffi_Instruction__5fnoargs$vmethods	soot_coffi_Instruction__5fnoargs;
	_jc_soot_coffi_Instruction__5fIrem$vmethods	soot_coffi_Instruction__5fIrem;
};

// Vtype
struct _jc_soot_coffi_Instruction__5fIrem$vtype {
	_jc_type			type;
	_jc_soot_coffi_Instruction__5fIrem$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fIrem$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fIrem$refs {
    _jc_soot_coffi_Instruction__5fIrem$sub_refs	soot_coffi_Instruction__5fIrem;
    _jc_soot_coffi_Instruction__5fnoargs$sub_refs	soot_coffi_Instruction__5fnoargs;
    _jc_soot_coffi_Instruction$sub_refs	soot_coffi_Instruction;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fIrem$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fIrem$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_coffi_Instruction$sub_nonrefs	soot_coffi_Instruction;
    _jc_soot_coffi_Instruction__5fnoargs$sub_nonrefs	soot_coffi_Instruction__5fnoargs;
    _jc_soot_coffi_Instruction__5fIrem$sub_nonrefs	soot_coffi_Instruction__5fIrem;
};

// Object instance structure
struct _jc_soot_coffi_Instruction__5fIrem$object {
	_jc_soot_coffi_Instruction__5fIrem$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_coffi_Instruction__5fIrem$vtype	*vtype;
	_jc_soot_coffi_Instruction__5fIrem$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_coffi_Instruction__5fIrem$vtype _jc_soot_coffi_Instruction__5fIrem$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_coffi_Instruction__5fIrem, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_coffi_Instruction__5fIrem$class_object;

#endif	/* _JC_soot_coffi_Instruction__5fIrem_H_ */
